<?php

namespace App\Http\Controllers\Api\Note;

use Illuminate\Http\Request;
use App\Traits\ResponseTrait;
use App\Interfaces\NoteInterface;
use App\Interfaces\UserInterface;
use App\Http\Controllers\Controller;
use App\Http\Requests\Note\NoteCreateRequest;

class NoteController extends Controller
{
    use ResponseTrait;

    protected $note, $user;

    public function __construct(
        NoteInterface $noteInterface,
        UserInterface $userInterface
        )
    {
        $this->note=$noteInterface;
        $this->user=$userInterface;
    }
    
    function createNote(NoteCreateRequest $request)
    {

        $user=$this->user->getAuthUser($request);

        $data=[];
        $data['title']=$request->input('title');
        $data['description']=$request->input('description');
        $data['user_id']=$user->id;

        try{
            $note=$this->note->PostNote($data);
            return $this->responseSuccess($note,'Note Created Success',200);
        }catch(\Exception $e){
            return $this->responseError($e->getMessage(),'Error',401);
        }



    }//end of createNote

    function getNotes(Request $request)
    {
        $user=$this->user->getAuthUser($request);

        try{
            $userNotes=$this->note->getStudentNotes($user->id);
            return $this->responseSuccess($userNotes,'Note Created Success',200);
        }catch(\Exception $e){
            return $this->responseError($e->getMessage(),'Error',401);
        }

    }//end of getNotes


    function getNote($id)
    {
        try{
            $editNote=$this->note->getNoteById($id);
            return $this->responseSuccess($editNote,'Note Update Success',200);
        }catch(\Exception $e){
            return $this->responseError($e->getMessage(),'Error',401);
        }

    }//end of getNote

    function updateNote(Request $request, $id)
    {
        $data=[];
        $data['title']=$request->input('title');
        $data['description']=$request->input('description');

       try{
        $updateNote=$this->note->updateNote($id,$data);
        return $this->responseSuccess($updateNote,'Note Update Success',200);
       }catch(\Exception $e){
        return $this->responseError($e->getMessage(),'Error',401);
       }

    }//end of updateNote

    function deleteNote($id)
    {
        try{
            $note=$this->note->deleteNote($id);
            return $this->responseSuccess($note,'Note Delete Success',200);
        }catch(\Exception $e){
            return $this->responseError($e->getMessage(),'Error',401);
        }

    }//end of deleteNote



}
