<?php

namespace App\Services;

use App\Traits\ConsumesExternalServices;
use Illuminate\Http\Request;


class PayPalService
{
    use ConsumesExternalServices;

    protected $baseUri;

    protected $clientId;

    protected $clientSecret;

    protected $plans;

    public function __construct()
    {
        $this->baseUri=config('services.paypal.base_uri');
        $this->clientId=config('services.paypal.client_id');
        $this->clientSecret=config('services.paypal.client_secret');
        $this->plans=config('services.paypal.plans');
    }


    public function resolveAuthorization(&$queryParams, &$formParams, &$headers)
    {
       $headers['Authorization']=$this->resolveAccessToken();
    }

    public function decodeResponse($response)
    {
        return json_decode($response);
    }

    public function resolveAccessToken()
    {
        $credentials=base64_encode("{$this->clientId}:{$this->clientSecret}");

        return "Basic {$credentials}";
    }


    public function createOrder($value, $currency)
    {
        return $this->makeRequest(
            'POST',
            '/v2/checkout/orders',
            [],
            [
                'intent'=>'CAPTURE',
                'purchase_units'=>[
                    0=>[
                        'amount'=>[
                            'currency_code'=>strtoupper($currency),
                            'value'=>$value
                        ]
                    ]
                ],
                'application_context'=>[
                    'brand_name'=>config('app.name'),
                    'shipping_preference'=>'NO_SHIPPING',
                    'user_action'=>'PAY_NOW',
                    'return_url'=>config('app.frontend_url').'/'.'approve',
                    'cancel_url'=>config('app.frontend_url').'/'.'cancel'
                ]

            ],
            [],
            $isJsonRequest=true
        );
    }//end of method

    public function capturePayment($approvalId)
    {
        return $this->makeRequest(
            'POST',
            "/v2/checkout/orders/{$approvalId}/capture",
            [],
            [],
            [
                'Content-type'=>'application/json'
            ]
        );
    }


    public function handleSubscription(Request $request)
    {
        $subscription=$this->createSubscription(
            $request->plan,
            "Mahedi",
            "Mahedi@gmail.com"
            // $request->user()->name,
            // $request->user()->email
        );

        $subscriptionLinks=collect($subscription->links);

        $approve=$subscriptionLinks->where('rel','approve')->first();

        session()->put('subscriptionId', $subscription->id);

        // return redirect($approve->href);

        return response()->json([
            'url'=>$approve->href
        ]);
    }

    public function createSubscription($planSlug, $name, $email)
    {
        return $this->makeRequest(
            'POST',
            '/v1/billing/subscriptions',
            [
                //request-form-params
            ],
            [
                //request-body-params
                'plan_id'=>$this->plans[$planSlug],
                'subscriber'=>[
                    'name'=>[
                        'given_name'=>$name
                    ],
                    'email_address'=>$email
                ],
                'application_context'=>[
                    'brand_name'=>config('app.name'),
                    'shipping_preference'=>'NO_SHIPPING',
                    'user_action'=>'SUBSCRIBE_NOW',
                    'return_url'=>config('app.frontend_url').'/subscription'."/approval?plan={$planSlug}",
                    'cancel_url'=>config('app.frontend_url').'/subscription'.'/cancel'
                ]
            ],
            [
                //request-header-config
                'Content-type'=>'application/json'
            ],
            $isJsonRequest=true
        );
    }//end of method

    public function subscriptionDetails($subscriptionId)
    {
        return $this->makeRequest(
            'GET',
            "/v1/billing/subscriptions/{$subscriptionId}",
            [
                //request-form-params
            ],
            [
                //request-body-params
            ],
            [
                //request-headers-config
                'Content-type'=>'application/json'
            ]
        );

    }



}


?>
