<?php

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\Api\Goal\GoalController;
use App\Http\Controllers\Api\Note\NoteController;
use App\Http\Controllers\Api\User\UserController;
use App\Http\Controllers\Api\Word\WordController;
use App\Http\Controllers\Api\Auth\LoginController;
use App\Http\Controllers\Api\Event\EventController;
use App\Http\Controllers\Api\Plan\SubscriptionPlan;
use App\Http\Controllers\Api\Auth\RegisterController;
use App\Http\Controllers\Api\Auth\VerifyEmailController;
use App\Http\Controllers\Api\Auth\ResetPasswordController;
use App\Http\Controllers\Api\Auth\ForgetPasswordController;
use App\Http\Controllers\Api\ConvertKit\ConvertKitController;
use App\Http\Controllers\Api\Subscription\PayPalSubscriptionController;
use App\Http\Controllers\Api\Subscription\StripeSubscriptionController;

Route::prefix('v1')->group(function () {
    //------------------------------Guest Routes Starts------------------------------------------//
    //-----register api
    Route::post('/register', [RegisterController::class, 'Register']);
    //-----login api
    Route::post('/login', [LoginController::class, 'Login']);
    //-----verify email address
    Route::post('/send/email/verification', [
        VerifyEmailController::class,
        'sendEmailVerification',
    ]);
    //-----forget-password
    Route::post('/forget-password', [
        ForgetPasswordController::class,
        'ForgetPassword',
    ])->name('forget.password');
    //-----reset-password
    Route::post('/reset-password', [
        ResetPasswordController::class,
        'ResetPassword',
    ])
        ->name('reset.password')
        ->middleware('signed');


    //-----verify email address
    Route::post('/verify-email', [
        VerifyEmailController::class,
        'verifyEmail',
    ])
        ->middleware('signed')
        ->name('verify-email');

    //convert-kit subscribe
    Route::post('/add/subscriber', [ConvertKitController::class, 'Subscribe']);

    //-------subscription-plans--------------------------
    Route::get('/plans', [SubscriptionPlan::class, 'getAllPlans']);

    //-------all payment gateway starts------------------------
    Route::prefix('paypal')->group(function () {
        Route::get('/subscribe', [
            PayPalSubscriptionController::class,
            'showSubscription',
        ]);
        Route::get('/subscription/{email}/details', [
            PayPalSubscriptionController::class,
            'subscriptionDetails',
        ]);
        Route::post('/process/subscription', [
            PayPalSubscriptionController::class,
            'processSubscription',
        ]);
        Route::get('/approval/subscription', [
            PayPalSubscriptionController::class,
            'approvalSubscription',
        ]);
        Route::get('/canceled/subscription', [
            PayPalSubscriptionController::class,
            'canceledSubscription',
        ]);
    });
    Route::prefix('stripe')->group(function () {
        Route::get('/subscribe', [
            StripeSubscriptionController::class,
            'showSubscription',
        ]);
        Route::get('/subscription/{email}/details', [
            StripeSubscriptionController::class,
            'userSubscriptionDetails',
        ]);
        Route::post('/process/subscription', [
            StripeSubscriptionController::class,
            'processSubscription',
        ]);
        Route::get('/approval/subscription', [
            StripeSubscriptionController::class,
            'approvalSubscription',
        ]);
        Route::get('/canceled/subscription', [
            StripeSubscriptionController::class,
            'canceledSubscription',
        ]);
    });
    //------all payment gateway ends------------------------

    //------------------------------Guest Routes  Ends------------------------------------------//

    //------------------------------Authenticated Routes Start------------------------------------------//
    Route::middleware(['auth:sanctum'])->group(function () {

        //-------users api--------------------------------
        Route::get('/user', [UserController::class, 'getUser']);
        Route::get('/user/{id}/edit', [UserController::class, 'editUser']);
        Route::put('/user/{id}/update', [UserController::class, 'updateUser']);

        //-------subscription-plans--------------------------
        // Route::get('/plans', [SubscriptionPlan::class, 'getAllPlans']);

        //-------all payment gateway------------------------
        // Route::prefix('paypal')->group(function () {
        //     Route::get('/subscribe', [
        //         PayPalSubscriptionController::class,
        //         'showSubscription',
        //     ]);
        //     Route::get('/subscription/{email}/details', [
        //         PayPalSubscriptionController::class,
        //         'subscriptionDetails',
        //     ]);
        //     Route::post('/process/subscription', [
        //         PayPalSubscriptionController::class,
        //         'processSubscription',
        //     ]);
        //     Route::get('/approval/subscription', [
        //         PayPalSubscriptionController::class,
        //         'approvalSubscription',
        //     ]);
        //     Route::get('/canceled/subscription', [
        //         PayPalSubscriptionController::class,
        //         'canceledSubscription',
        //     ]);
        // });

        // Route::prefix('stripe')->group(function () {
        //     Route::get('/subscribe', [
        //         StripeSubscriptionController::class,
        //         'showSubscription',
        //     ]);
        //     Route::get('/subscription/{email}/details', [
        //         StripeSubscriptionController::class,
        //         'userSubscriptionDetails',
        //     ]);
        //     Route::post('/process/subscription', [
        //         StripeSubscriptionController::class,
        //         'processSubscription',
        //     ]);
        //     Route::get('/approval/subscription', [
        //         StripeSubscriptionController::class,
        //         'approvalSubscription',
        //     ]);
        //     Route::get('/canceled/subscription', [
        //         StripeSubscriptionController::class,
        //         'canceledSubscription',
        //     ]);
        // });

        //------------------------Note-------------------------------------------//
        Route::post('/create/note', [NoteController::class, 'createNote']);
        Route::get('/notes', [NoteController::class, 'getNotes']);
        Route::get('/note/{id}', [NoteController::class, 'getNote']);
        Route::put('/note/{id}', [NoteController::class, 'updateNote']);
        Route::delete('/note/{id}', [NoteController::class, 'deleteNote']);
        //------------------------Note-------------------------------------------//

        //------------------------Event-------------------------------------------//
        Route::post('/create/event', [EventController::class, 'createEvent']);
        Route::get('/events', [EventController::class, 'getEvents']);
        Route::get('/event/{id}', [EventController::class, 'getEvent']);
        Route::put('/event/{id}', [EventController::class, 'updateEvent']);
        Route::delete('/event/{id}', [EventController::class, 'deleteEvent']);
        //------------------------Event-------------------------------------------//

        //------------------------Goal-------------------------------------------//
        Route::post('/create/goal', [GoalController::class, 'createGoal']);
        Route::get('/goals', [GoalController::class, 'getGoals']);
        Route::get('/goal/{id}', [GoalController::class, 'getGoal']);
        Route::put('/goal/{id}', [GoalController::class, 'updateGoal']);
        Route::delete('/goal/{id}', [GoalController::class, 'deleteGoal']);
        //------------------------Goal-------------------------------------------//

        //------------------------Word-------------------------------------------//
        Route::post('/create/word', [WordController::class, 'createWord']);
        Route::get('/words', [WordController::class, 'getWords']);
        Route::get('/word/{id}', [WordController::class, 'getWord']);
        Route::put('/word/{id}', [WordController::class, 'updateWord']);
        Route::delete('/word/{id}', [WordController::class, 'deleteWord']);
        //------------------------Word-------------------------------------------//
    });
    //------------------------------Authenticated Routes End--------------------------------------------//
});
